@@ -105,8 +105,6 @@ class Dataset:
         logger.info(f"Dataset: {self.num_data}\n{_repr}")
 
     def __repr__(self):
-        # _repr = "\n".join([f"{k}: {', '.join([str(_v) for _v in v]) if len(v) < 10 else ', '.join([str(_v) for i, _v in zip(range(10), v)])+', ...'}" for k, v in self._key_values.items()])
-        # _repr = re.sub(r"^", " " * 4, _repr, 0, re.M)
         return f"Dataset: {self.num_data}\n"
 
     def __iter__(self):
@@ -114,7 +112,7 @@ class Dataset:
 
 
 class DataLoader:
-    def __init__(self, dataset: Dataset, shuffle: bool = False, batch_size: int = 1, collate_fn: Optional[Callable] = None, prefetch_factor: int = 1, num_workers: int = 1, format: Optional[str] = None, padding_value: int = -100, **kwargs) -> None:
+    def __init__(self, dataset: Dataset, shuffle: bool = False, batch_size: int = 1, collate_fn: Optional[Callable] = None, prefetch_factor: int = 1, num_workers: int = 1, format: Optional[str] = None, padding_value: int = 0, **kwargs) -> None:
         self.dataset = dataset
         self._shuffle = shuffle
         self._batch_size = batch_size
@@ -122,6 +120,7 @@ class DataLoader:
         self._prefetch_factor = prefetch_factor
         self._num_workers = num_workers
         self._format = format if format in {"tf", "torch"} else "numpy"
+        self._padding_value = padding_value
         self._gen = PrefetchGenerator(self.dataset._data, num_prefetch=self._prefetch_factor*self._batch_size, num_workers=self._num_workers, shuffle=self._shuffle, processing_func=self._collate_fn, name="DataLoader")
 
     def as_format(self, batch):
@@ -141,9 +140,9 @@ class DataLoader:
                         datas[i] = np.array(data)
                     else:
                         padded_begin = np.zeros(max_len.shape).astype(np.int32)
-                        datas[i] = np.array([np.pad(d, np.stack((padded_begin, max_len - d.shape)).T) for d in data])                        
+                        datas[i] = np.array([np.pad(d, np.stack((padded_begin, max_len - d.shape)).T, constant_values=self._padding_value) for d in data])                        
             else:
-                raise ValueError("데이터 크기가 다릅니다.")
+                raise ValueError("collate_fn에서 출력하는 데이터의 개수가 동일하지 않습니다.")
         else:
             raise ModuleNotFoundError("numpy")
         if self._format == "tf":
