@@ -130,7 +130,7 @@ class PrefetchGenerator(Thread):
         """
 
         def assign(iterable, units):
-            if not hasattr(iterable, "__len__") and self.shuffle:
+            if hasattr(iterable, "__len__") and self.shuffle:
                 iterable = iterable[:]
                 random.shuffle(iterable)
             num_units = len(units)
